@@ -157,6 +157,12 @@ GIcon                    *xfce_gicon_from_name                            (const
 void                      xfce_gtk_menu_item_set_accel_label              (GtkMenuItem               *menu_item,
                                                                            const gchar               *accel_path);
 
+gboolean                  xfce_has_gtk_frame_extents                      (GdkWindow                 *window,
+                                                                           GtkBorder                 *extents);
+
+void                      xfce_gtk_label_set_a11y_relation                (GtkLabel                  *label,
+                                                                           GtkWidget                 *widget);
+
 G_END_DECLS
 
 #endif /* !__XFCE_GTK_EXTENSIONS_H__ */
